@@ -1,9 +1,11 @@
-import abc
 from collections.abc import Iterable
 from typing import Optional
 
 from discord import Reaction, Message, Member, RawReactionActionEvent
 
+from discordmenu.embed.emoji import DEFAULT_EMBED_MENU_EMOJI_CONFIG, EmbedMenuEmojiConfig
+from discordmenu.emoji_cache import discord_emoji_to_emoji_name
+
 
 class ReactionFilter:
     def __init__(self, reaction_filter: Optional["ReactionFilter"] = None):
@@ -11,17 +13,17 @@ class ReactionFilter:
 
     async def allow_reaction(self, message: Message, reaction: Reaction, member: Member):
         parent = await self._allow_reaction(message, reaction, member)
-        if not parent:
-            return False
+        if parent:
+            return True
 
-        return await self.inner_filter.allow_reaction(message, reaction, member) if self.inner_filter else True
+        return await self.inner_filter.allow_reaction(message, reaction, member) if self.inner_filter else False
 
     async def allow_reaction_raw(self, message: Message, reaction: RawReactionActionEvent):
         parent = await self._allow_reaction_raw(message, reaction)
-        if not parent:
-            return False
+        if parent:
+            return True
 
-        return await self.inner_filter.allow_reaction_raw(message, reaction) if self.inner_filter else True
+        return await self.inner_filter.allow_reaction_raw(message, reaction) if self.inner_filter else False
 
     async def _allow_reaction(self, message: Message, reaction: Reaction, member: Member):
         return True
@@ -31,16 +33,21 @@ class ReactionFilter:
 
 
 class ValidEmojiReactionFilter(ReactionFilter):
-    def __init__(self, valid_emoji_names: Iterable, filters: Optional[ReactionFilter] = None):
+    def __init__(self, valid_emoji_names: Iterable, default_emoji_override: EmbedMenuEmojiConfig = None,
+                 filters: Optional[ReactionFilter] = None):
         super().__init__(filters)
-        self.valid_emoji_names = valid_emoji_names
+        default_emojis = default_emoji_override or DEFAULT_EMBED_MENU_EMOJI_CONFIG
+        emoji_set = set(default_emojis.to_list())
+        emoji_set.update(valid_emoji_names)
+        self.valid_emoji_names = list(emoji_set)
 
     async def _allow_reaction(self, message: Message, reaction: Reaction, member: Member):
-        valid_emoji_reaction = str(reaction.emoji.name) in self.valid_emoji_names
+        valid_emoji_reaction = discord_emoji_to_emoji_name(reaction.emoji) in self.valid_emoji_names
+        print("valid emo", valid_emoji_reaction)
         return valid_emoji_reaction
 
     async def _allow_reaction_raw(self, message: Message, reaction: RawReactionActionEvent):
-        valid_emoji_reaction = str(reaction.emoji.name) in self.valid_emoji_names
+        valid_emoji_reaction = discord_emoji_to_emoji_name(reaction.emoji) in self.valid_emoji_names
         return valid_emoji_reaction
 
 
@@ -63,7 +70,9 @@ class MessageOwnerReactionFilter(ReactionFilter):
         super().__init__(filters)
         self.original_author_id = original_author_id
 
-    @abc.abstractmethod
+    async def _allow_reaction(self, message: Message, reaction: Reaction, member: Member):
+        return member.id == self.original_author_id
+
     async def _allow_reaction_raw(self, message: Message, reaction: RawReactionActionEvent):
         if reaction.guild_id:
             return reaction.member.id == self.original_author_id
